Enum SSWTPlanMemoryMode
#[non_exhaustive]pub enum SSWTPlanMemoryMode {
Balanced,
Fast,
}Expand description
Planned SSWT memory/performance policy.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Balanced
Avoid transient partial output planes during reassignment.
This still reuses the plan’s CWT wavelet spectrum cache and the thread-local flat CWT coefficient scratch buffer, but keeps the reassignment pass single-output-plane.
Fast
Use capped parallel reassignment for large transforms.
This is faster on large scale-time/output planes, but can allocate up to four transient partial output planes.